## 0.4.0 (2025-05-19)

### Feat

- **Add-github-actions-for-linting-and-testing**: writing actions for automated linting and testing

### Fix

- rename action file

## 0.3.0 (2025-05-19)

### Feat

- **Added-commitizen-for-automated-versioning**: added the necessary dependencies

## v0.5.2 (2025-05-20)

### Fix

- **authentication.py**: remove support to load settings from .env (#3)

## v0.5.1 (2025-05-20)

## v0.5.0 (2025-05-20)

### BREAKING CHANGE

- pe of change you are committing docs: Documentation only changes

## v0.3.0 (2025-05-19)

### Feat

- **Added-commitizen-for-automated-versioning**: added the necessary dependencies
